@@ -50,9 +50,7 @@ def retrieve_the_metabase_cards_using_sql_query_with_a_table(
             "schema_name": schema_name,
         }
     )
-    query_file_path = (
-        "query/get_metabase_cards_with_specific_sql_query.sql"
-    )
+    query_file_path = "query/get_metabase_cards_with_specific_sql_query.sql"
     df_metabase_fields = select_table(conn, query_file_path, variables)
     return df_metabase_fields
 
@@ -63,9 +61,7 @@ def delete_a_metabase_field_based_on_id(conn, metabase_field_id):
             "metabase_field_id": int(metabase_field_id),
         }
     )
-    query_file_path = (
-        "deletion/delete_metabase_field_based_on_id.sql"
-    )
+    query_file_path = "deletion/delete_metabase_field_based_on_id.sql"
     try:
         updated_row = alter_table(conn, query_file_path, variables)
         if updated_row == 0:
@@ -85,9 +81,7 @@ def delete_a_metabase_field_based_on_schema(conn, schema_name):
             "schema_name": schema_name,
         }
     )
-    query_file_path = (
-        "deletion/delete_metabase_table_based_on_schema_name.sql"
-    )
+    query_file_path = "deletion/delete_metabase_table_based_on_schema_name.sql"
     try:
         updated_row = alter_table(conn, query_file_path, variables)
         print(
@@ -106,9 +100,7 @@ def delete_a_metabase_table_based_on_id(conn, metabase_table_id):
             "metabase_table_id": int(metabase_table_id),
         }
     )
-    query_file_path = (
-        "deletion/delete_metabase_table_based_on_id.sql"
-    )
+    query_file_path = "deletion/delete_metabase_table_based_on_id.sql"
     try:
         updated_row = alter_table(conn, query_file_path, variables)
         if updated_row == 0:
@@ -163,9 +155,7 @@ def rename_table_and_activate_metabase_table(
             "old_table_id": int(old_table_id),
         }
     )
-    query_file_path = (
-        "update/update_table_name_in_metabase_table.sql"
-    )
+    query_file_path = "update/update_table_name_in_metabase_table.sql"
     try:
         updated_row = alter_table(conn, query_file_path, variables)
         if updated_row == 0:
@@ -214,9 +204,7 @@ def update_report_card_with_new_column(
             "updated_dataset_query_json": updated_dataset_query_json,
         }
     )
-    query_file_path = (
-        "update/update_column_name_in_sql_query.sql"
-    )
+    query_file_path = "update/update_column_name_in_sql_query.sql"
     try:
         updated_row = alter_table(conn, query_file_path, variables)
         if updated_row == 0:
@@ -239,9 +227,7 @@ def update_schema_name_for_all_tables(conn, old_schema_name, new_schema_name):
             "new_schema_name": new_schema_name,
         }
     )
-    query_file_path = (
-        "update/update_metabase_table_schema_name.sql"
-    )
+    query_file_path = "update/update_metabase_table_schema_name.sql"
     try:
         updated_row = alter_table(conn, query_file_path, variables)
         if updated_row == 0:
